@@ -101,7 +101,6 @@ class GLXShell(
         persistent_history_file: str = "",
         persistent_history_length: int = 1000,
         startup_script: str = "",
-        use_ipython: bool = False,
         allow_cli_args: bool = True,
         transcript_files: Optional[List[str]] = None,
         allow_redirection: bool = True,
@@ -140,7 +139,6 @@ class GLXShell(
             persistent_history_file=self.persistent_history_file,
             persistent_history_length=self.persistent_history_length,
             startup_script=startup_script,
-            use_ipython=use_ipython,
             allow_cli_args=allow_cli_args,
             transcript_files=transcript_files,
             allow_redirection=allow_redirection,
