@@ -362,7 +362,7 @@ class GLXCd(cmd2.CommandSet):
                 else:
                     if os.environ.get("OLDPWD") != os.environ["PWD"]:
                         os.environ["OLDPWD"] = os.environ["PWD"]
-                    if os.environ["PWD"] != os.path.normpath(os.getcwd()):
+                    if os.environ.get("PWD") != os.path.normpath(os.getcwd()):
                         os.environ["PWD"] = os.path.normpath(os.getcwd())
 
             if err:
